# aconnection

<a href="https://pypi.org/project/aconnection" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/aconnection.svg?color=%2334D058" alt="Supported Python versions">
</a>
<a href="https://pypi.org/project/aconnection" target="_blank">
    <img src="https://img.shields.io/pypi/v/aconnection?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
<a href="https://github.com/VolodymyrBor/aconnection/actions/workflows/build.yml?branch=main" target="_blank">
    <img src="https://github.com/VolodymyrBor/aconnection/actions/workflows/build.yml/badge.svg?branch=master" alt="Test">
</a>

[![Supported Versions](https://img.shields.io/badge/coverage-100%25-green)](https://shields.io/)
[![Supported Versions](https://img.shields.io/badge/poetry-✅-grey)](https://shields.io/)
[![Supported Versions](https://img.shields.io/badge/async-✅-grey)](https://shields.io/)
[![Supported Versions](https://img.shields.io/badge/pyrefly-✅-grey)](https://shields.io/)

---

**aconnection** - providers the following abc classes:
- Sync:
  - Closeable
  - Connectable
  - ResourceManager
  - ConnectionManager
- Async:
  - AsyncCloseable
  - AsyncConnectable
  - AsyncResourceManager
  - AsyncConnectionManager

---
